==> haskell-primitive-0.6.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-primitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6.1.0
id: primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
key: primi_EphY2c7CCxSCBKjAN0YTR3
license: BSD3
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.MachDeps
    Data.Primitive.Types Data.Primitive.Array Data.Primitive.ByteArray
    Data.Primitive.Addr Data.Primitive.MutVar
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/primitive-0.6.1.0
hs-libraries: HSprimitive-0.6.1.0-EphY2c7CCxSCBKjAN0YTR3
include-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6.1.0/include
includes:
    primitive-memops.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.6-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-primitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6
id: primitive-0.6-e792418f7dbd95c8907334653976b3c4
key: primi_7kZ35LLc1NHAz4jbBp6unU
license: BSD3
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.MachDeps
    Data.Primitive.Types Data.Primitive.Array Data.Primitive.ByteArray
    Data.Primitive.Addr Data.Primitive.MutVar
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/primitive-0.6
hs-libraries: HSprimitive-0.6-7kZ35LLc1NHAz4jbBp6unU
include-dirs: /usr/lib/ghc-7.10.3/site-local/primitive-0.6/include
includes:
    primitive-memops.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
